@@ -8,4 +8,8 @@ class TwitterException(Exception):
         super(TwitterException, self).__init__(message)
         if errors is None:
             errors = []
+        self.message = message
         self.errors = errors
+
+    def __repr__(self):
+        return self.message
